@@ -1,5 +1,7 @@
 """
-Main interface for ebs service client
+Type annotations for ebs service client.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html)
 
 Usage::
 
@@ -56,7 +58,8 @@ class Exceptions:
 
 class EBSClient:
     """
-    [EBS.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/ebs.html#EBS.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html)
     """
 
     meta: ClientMeta
@@ -64,7 +67,8 @@ class EBSClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/ebs.html#EBS.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#can-paginate)
         """
 
     def complete_snapshot(
@@ -76,7 +80,8 @@ class EBSClient:
         ChecksumAggregationMethod: Literal["LINEAR"] = None,
     ) -> CompleteSnapshotResponseTypeDef:
         """
-        [Client.complete_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/ebs.html#EBS.Client.complete_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.complete_snapshot)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#complete-snapshot)
         """
 
     def generate_presigned_url(
@@ -87,14 +92,16 @@ class EBSClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/ebs.html#EBS.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#generate-presigned-url)
         """
 
     def get_snapshot_block(
         self, SnapshotId: str, BlockIndex: int, BlockToken: str
     ) -> GetSnapshotBlockResponseTypeDef:
         """
-        [Client.get_snapshot_block documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/ebs.html#EBS.Client.get_snapshot_block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.get_snapshot_block)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#get-snapshot-block)
         """
 
     def list_changed_blocks(
@@ -106,7 +113,8 @@ class EBSClient:
         StartingBlockIndex: int = None,
     ) -> ListChangedBlocksResponseTypeDef:
         """
-        [Client.list_changed_blocks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/ebs.html#EBS.Client.list_changed_blocks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.list_changed_blocks)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#list-changed-blocks)
         """
 
     def list_snapshot_blocks(
@@ -117,7 +125,8 @@ class EBSClient:
         StartingBlockIndex: int = None,
     ) -> ListSnapshotBlocksResponseTypeDef:
         """
-        [Client.list_snapshot_blocks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/ebs.html#EBS.Client.list_snapshot_blocks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.list_snapshot_blocks)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#list-snapshot-blocks)
         """
 
     def put_snapshot_block(
@@ -131,7 +140,8 @@ class EBSClient:
         Progress: int = None,
     ) -> PutSnapshotBlockResponseTypeDef:
         """
-        [Client.put_snapshot_block documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/ebs.html#EBS.Client.put_snapshot_block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.put_snapshot_block)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#put-snapshot-block)
         """
 
     def start_snapshot(
@@ -146,5 +156,6 @@ class EBSClient:
         Timeout: int = None,
     ) -> StartSnapshotResponseTypeDef:
         """
-        [Client.start_snapshot documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.53/reference/services/ebs.html#EBS.Client.start_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.start_snapshot)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#start-snapshot)
         """
